package com.taauav.admin.service.impl;

import com.taauav.common.bean.Response;
import com.taauav.admin.entity.TauvInspect;
import com.taauav.admin.mapper.TauvInspectMapper;
import com.taauav.admin.service.ITauvInspectDriverService;
import com.taauav.admin.service.ITauvInspectService;
import com.taauav.common.service.impl.BaseServiceImpl;
import com.taauav.common.util.DateUtil;
import com.taauav.common.util.FunctionUtils;
import com.taauav.common.util.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;


/**
 * <p>
 * 巡检任务表 服务实现类
 * </p>
 *
 * @author dyg
 * @since 2019-11-14
 */
@Service
public class TauvInspectServiceImpl extends BaseServiceImpl<TauvInspectMapper, TauvInspect> implements ITauvInspectService {
    @Autowired
    private Response response;
    @Autowired
    private TauvInspectMapper inspectMapper;
    @Autowired
    private ITauvInspectDriverService iTauvInspectDriverService;

    /**
     * 添加任务
     *
     * @param inspect
     * @return
     */
    @Override
    public Response addTask(TauvInspect inspect) {
        // 巡检类型校验
        if (inspect.getType() == null || inspect.getType() <= 0) {
            return response.failure("请选择巡检类型");
        }
        // 创建巡检任务
        boolean result = this.addData(inspect);
        if (!result) {
            return response.failure("巡检任务创建失败");
        }

        // 生成巡检任务单号
        String code = "";
        if (inspect.getType() == 1) {
            // 可见光巡检
            code = "KJG" + FunctionUtils.formatTime(FunctionUtils.getCurrentTime(), "yyyyMM");
        } else if (inspect.getType() == 2) {
            // 多光谱巡检
            code = "DGP" + FunctionUtils.formatTime(FunctionUtils.getCurrentTime(), "yyyyMM");
        }
        Integer id = inspect.getId();
        String idStr = String.format("%04d", id);
        inspect.setId(id);
        inspect.setInspectNo(code + idStr);
        saveOrUpdate(inspect);
        String msg = iTauvInspectDriverService.batchAddData(inspect);
        if (!"".equals(msg)) {
            return response.failure(msg);
        }
        return response.success("添加成功");
    }

    @Override
    public TauvInspect getInfoById(Integer id) {
        return inspectMapper.selectById(id);
    }
}
